@@ -3,13 +3,23 @@ import subprocess
 import sys
 import json
 import tempfile
+from getpass import getuser
 from pathlib import Path
 from typing import Any, NoReturn, Union
 
-from . import node
+from . import node, __pyright_version__
 
 
-TEMP_DIR = Path(tempfile.gettempdir()) / 'pyright-python-langserver'
+def get_temp_dir() -> Path:
+    try:
+        suffix = f'.{getuser()}'
+    except Exception:
+        suffix = ''
+
+    return Path(tempfile.gettempdir()) / f'pyright-python-langserver{suffix}'
+
+
+TEMP_DIR = get_temp_dir()
 
 
 def main(*args: str, **kwargs: Any) -> int:
@@ -22,7 +32,7 @@ def run(
 ) -> Union['subprocess.CompletedProcess[bytes]', 'subprocess.CompletedProcess[str]']:
     TEMP_DIR.mkdir(exist_ok=True, parents=True)
 
-    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION')
+    version = os.environ.get('PYRIGHT_PYTHON_FORCE_VERSION', __pyright_version__)
     if version is None:
         version = node.latest('pyright')
 
